changeset 72536:59670fc88353

(mac-apple-event-map): Rename hicommand to hi-command. (mac-dnd-drop-data): Apply 2006-08-22 change for x-dnd-drop-data. (special-event-map): Apply 2006-08-16 change for x-win.el.
author YAMAMOTO Mitsuharu <mituharu@math.s.chiba-u.ac.jp>
date Sun, 27 Aug 2006 07:08:07 +0000
parents e7ed98d0f919
children 07b45e10e844
files lisp/term/mac-win.el
diffstat 1 files changed, 6 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/term/mac-win.el	Sat Aug 26 14:39:16 2006 +0000
+++ b/lisp/term/mac-win.el	Sun Aug 27 07:08:07 2006 +0000
@@ -1539,7 +1539,7 @@
 (put 'autosave-now       'mac-apple-event-id "asav") ; kAEAutosaveNow
 ;; kAEInternetEventClass
 (put 'get-url            'mac-apple-event-id "GURL") ; kAEGetURL
 ;; Converted HICommand events
 (put 'about              'mac-apple-event-id "abou") ; kHICommandAbout
 
 (defmacro mac-event-spec (event)
@@ -1739,7 +1739,7 @@
 
 (define-key mac-apple-event-map [internet-event get-url] 'mac-ae-get-url)
 
-(define-key mac-apple-event-map [hicommand about] 'display-splash-screen)
+(define-key mac-apple-event-map [hi-command about] 'display-splash-screen)
 
 ;;; Converted Carbon Events
 (defun mac-handle-toolbar-switch-mode (event)
@@ -2208,7 +2208,8 @@
 	  ;; If dropping in an ordinary window which we could use,
 	  ;; let dnd-open-file-other-window specify what to do.
 	  (progn
-	    (goto-char (posn-point (event-start event)))
+	    (when (not mouse-yank-at-point)
+	      (goto-char (posn-point (event-start event))))
 	    (funcall handler window action data))
 	;; If we can't display the file here,
 	;; make a new window for it.
@@ -2561,8 +2562,8 @@
 
 ;; Initiate drag and drop
 
-(global-set-key [drag-n-drop] 'mac-dnd-handle-drag-n-drop-event)
-(global-set-key [M-drag-n-drop] 'mac-dnd-handle-drag-n-drop-event)
+(define-key special-event-map [drag-n-drop] 'mac-dnd-handle-drag-n-drop-event)
+(define-key special-event-map [M-drag-n-drop] 'mac-dnd-handle-drag-n-drop-event)
 
 
 ;;;; Non-toolkit Scroll bars
@@ -1539,7 +1539,7 @@
 ;; kAEInternetEventClass
 (put 'get-url            'mac-apple-event-id "GURL") ; kAEGetURL
-;; Converted HICommand events
+;; Converted HI command events
 (put 'about              'mac-apple-event-id "abou") ; kHICommandAbout
 